@@ -16,8 +16,20 @@ $Id: $
 """
 
 from zope import interface
+from zope.component.interfaces import IObjectEvent
 
 class IApplication( interface.Interface ):
     """
-    Application to publish
+    Application Root to publish
     """
+
+class IWSGIApplicationCreatedEvent( IObjectEvent ):
+    
+    app = interface.Attribute(u"Published Application")
+
+class WSGIApplicationCreatedEvent( object ):
+    
+    interface.implements( IWSGIApplicationCreatedEvent )
+    
+    def __init__( self, object ):
+        self.object = object
\ No newline at end of file
